<a id="initialize-app"></a>

### 初始化 App

如果您开发过 Vue 程序，您会知道，在您的 Web 程序中，会拥有一个或多个 Vue 跟视图对象，在 Vert 中，我们将跟视图对象叫做 `App`.

下面的例子将指导您如何创建一个 App：

```html
<!-- 程序视图. -->

<html>
  <head>
    <title>App Index</title>
  </head>
  
  <body>
    <div id="app-index"></div>
  </body>
</html>
```

```typescript
// 创建一个 App 实例来初始化一个页面。
// 项目入口文件.

import { App } from '@vert/core'
import RootComponent from './root-component/index.vue'

const app = new App({
  element: '#app-index',
  name: 'app-index',
  RootComponent
})

app.start()
```

您的程序可以同时有多个 App：

```html
<html>
  <head>
    <meta charset="utf-8">
    <title>Multi apps in one page</title>
  </head>

  <body>
    <div id="header-vm"></div>
    <div id="main-vm"></div>
  </body>
</html>
```

```typescript
import { App } from '@vert/core'
import { Store } from 'vuex'

import HeaderComponent from './header/index.vue'
import MainComponent from './main/index.vue'

const headerVM = new App({
  element: '#header-vm',
  RootComponent: HeaderComponent,
  store: new Store({
    state: { name: 'Header VM' },
    getters: {
      getName (state) { return state.name }
    }
  })
})

const mainVM = new App({
  element: '#main-vm',
  RootComponent: MainComponent,
  store: new Store({
    state: { name: 'Main VM' },
    getters: {
      getName (state) { return state.name }
    }
  })
})

headerVM.start()
mainVM.start()
```

至此，您的程序创建完成.
