<a id="di-for-class"></a>

### 编写可注入的 Class 并注入至其他 Class 中

在 Vert 中，您将不可避免地使用 `Class` 进行开发，因为它的目标是创建 OOP 程序。

如果您熟悉面向对象，您经常会使用 `依赖注入` 的方式来实现 `控制反转`，Vert 同样提供此项功能：

> 关于依赖注入（DI）和控制反转（IOC）的作用与目的，您可以通过参考其他文献来了解详细内容.

```typescript
class Student {
  name = 'John Smith'
  age = 27
}
```

您创建一了一个类 `Student`，现在请加入装饰器 `Injectable`：

```typescript
import { Injectable } from '@vert/core'

@Injectable()
class Student {
  learn () {}
  doHomework () {}
}
```

此时，类 Student 就可以注入至被 `@Injectable()` 装饰的类中：

```typescript
// 我们创建一个新的叫做 ClassRoom 的类，然后注入 Student 类.

import { Injectable } from '@vert/core'

// 请加入 @Injectable 装饰器，否则无法顺理注入.
@Injectable()
class ClassRoom {
  constructor (public student: Student) {
    // this.student.learn()
    // this.student.doHomework()
  }
}
```

当然，也可以注入至被 `@Component` 装饰的 `AppComponent` 中，此内容将在下一章节讨论：

```typescript
// 我们将 Student 也尝试注入到一个视图组件中：

import { AppComponent, Component } from '@vert/core'

@Component
export default class RootComponent extends AppComponent {
  constructor (private student: Student) {
    super()
    // this.student.learn()
    // this.student.doHomework()
  }
}
```

最后，您需要在程序开始位置为您的程序添加注入实例.

请新建一个 ts 文件，比如叫做 `startup.ts`，然后在文件中输入以下代码：

```typescript
// startup.ts

import { App, Injector } from '@vert/core'
import { ClassRoom } from './classroom'

const injector = Injector.create(ClassRoom)
const classRoom = injector.get(ClassRoom)

// 为您的程序添加一个 classRoom 实例.
App.addSingleton(ClassRoom, classRoom)
```

然后在您的程序主文件顶部引入此文件：

```typescript
import 'reflect-metadata'
import 'babel-polyfill'
import './startup'  // 在您的程序顶部位置引入此文件.
```

上方代码使用了 `Injector` 组件对类进行初始化：

```typescript
import { Injectable, Injector } from '@vert/core'

@Injectable()
class A {
  a = 'a'
}

@Injectable()
class B {
  b = 'b'
}

const injector = Injector.create(A, B)
const a = injector.get(A)
const b = injector.get(B)
```

> 相关阅读：[将一个类注入至 AppComponent 中](#di-for-app-component)，[]()
