<a id="di-for-app-component"></a>

### 将一个类注入至 AppComponent 中

和上一章节相似，您不仅可以将一个类注入到另一个类中，还可以将一个类注入至 `AppComponent` 当中：

```typescript
// user.ts
// 您编写了一个 User 类，并打算在其他地方使用此类.

import { Inject, Injectable } from '@vert/core'
import { Http } from '@vert/services'

@Injectable()
class User {
  async getUserInfoById (id: number) {
    const result = { data: null, error: null }

    try {
      const { data } = await this.http.get(`/api/v1/user?id=${id}`)
      result.data = data
    } catch (error) {
      result.error = error
    }
    
    return result
  }

  constructor (private http: Http) {}
}

export {
  User
}
```

确保您已经在程序头部创建 User 实例并注册：

```typescript
import { App, Injector } from '@vert/core'
import { User } from './user'

const injector = Injector.create(User)
const user = injector.get(User)

App.addSingleton(User, user)
```

然后在您的组件中使用：

```typescript
// root-component.ts
// 您打算在这个组件引入 User 类.

import { AppComponent, Component } from '@vert/core'
import { User } from './services.ts'

@Component
export default class RootComponent extends AppComponent {
  userId: number = null
  userInfo: {} = {}

  async fetchAuthorList () {
    const { data, error } = await this.user.getUserInfoById(this.userId)
    if (!error) {
      this.userInfo = data
    }
  }
  
  constructor (public user: User) {
    super()
  }
}
```
